<?php 
/*
Plugin Name: NSRC Lernkorb
Plugin URI: http://www.haw-hamburg.de
Description: Dieses Plugin ergänzt: Anzeigen/hinzufügen von Lernerlis (Lernthemen) und ändern der Aneignungsstufe; Anzeige des Lernwunschkorbs und Druckansicht; Anlegen eines Lernerlis: [lernerli]Ich bin das Lernerli[/lernerli]; Anzeigen des Lernwunschkorbs [lernwunschkorb/].
Version: 1.2 (22.05.2021)
Author: Hamburg Open Online University (HOOU) / Netsource Data Systems

Requires at least: 5.5.3
License:           MIT
License URI:       https://opensource.org/licenses/mit-license.php

TODO: eventuell eigenen Block für Lernerlis (https://developer.wordpress.org/block-editor/developers/block-api/block-registration/)
*/

require_once "NSRC-lernkorb-options.php";
require_once "NSRC-lernkorb-backend-options.php";
require_once "NSRC-lernkorb-frontend-options.php";
require_once "NSRC-lernkorb-frontend-shortcodes.php";
require_once "NSRC-lernkorb-queryvars.php";
require_once "NSRC-lernkorb-quicktags.php";

//backend
add_action(     'admin_menu',                   array('NSRCLernkorbBackendOptions','nsrc_add_adminmenu_description_lernkorb') );
add_action(     'admin_print_footer_scripts',   array('NSRCLernkorbQuicktags','nsrc_lernerli_quicktag') );
add_action(     'admin_print_footer_scripts',   array('NSRCLernkorbQuicktags','nsrc_lernwunschkorb_quicktag') );
add_action(     'save_post',                    array('NSRCLernkorbQuicktags','nsrc_lernerli_quicktag_save_post'),10,3 );
add_action(     'updated_post_meta',              array('NSRCLernkorbQuicktags','nsrc_lernerli_quicktag_update_postmeta'),10,4 );
add_filter(     'plugin_action_links_' . plugin_basename(__FILE__), array('NSRCLernkorbBackendOptions','nsrc_add_pluginlinks') );

//frontend
add_action(     'wp_head',                      array('NSRCLernkorbFrontendOptions','nsrc_add_javascript_head'));
add_action(     'wp_head',                      array('NSRCLernkorbFrontendOptions','nsrc_add_css_head'));
add_shortcode(  'lernkreis',                    array('NSRCLernkorbFrontendShortcodes','nsrc_lernkreis_shortcode_user') );
add_shortcode(  'lernerli_kreis',               array('NSRCLernkorbFrontendShortcodes','nsrc_lernkreis_shortcode_post') );
add_shortcode(  'lernwunschkorb',               array('NSRCLernkorbFrontendShortcodes','nsrc_lernwunschkorb_shortcode') );
add_filter( 	'get_post_metadata', 			array('NSRCLernkorbFrontendShortcodes','nsrc_lernkreise_post' ));
add_filter( 	'the_content', 					array('NSRCLernkorbFrontendShortcodes','nsrc_lernkreise_post' ));
add_action(     'parse_query',                  array('NSRCLernkorbQueryvars', 'nsrc_add_lernerli_2_user'));
add_filter(     'query_vars',                   array('NSRCLernkorbQueryvars', 'nsrc_add_query_vars' ));
add_filter(     'body_class',                   array('NSRCLernkorbFrontendShortcodes','nsrc_css_class_shortcode' ));
add_action(     'wp_footer',                    array('NSRCLernkorbFrontendShortcodes','nsrc_toogle_javascript' ));


class Lernkorb {
    const LERNERLI_id = "lernerli";
    const LERNERLI_title = "Lernerli";
    const LERNERLI_2user_param = "lernerliUser";
    const LERNERLI_2_param = "lernerli";
    const LERNERLI_2_stufe = "lernerliStufe";
    const LERNWUNSCHKORB_id = "lernwunschkorb";
    const LERNWUNSCHKORB_title = "Lernwunschkorb";

    /**
     * Load complete Metadata for post with given key
     */
    function get_complete_meta( $post_id, $meta_key="" ) {
        global $wpdb;
        $mid = $wpdb->get_results( $wpdb->prepare("SELECT * FROM $wpdb->postmeta WHERE post_id = %d AND meta_key = %s", $post_id, $meta_key) );
        if( $mid != '' )
            return $mid;
        else
            return false;
    }

    /**
     * Load complete Metadata for post
     */
    function get_complete_meta_post( $post_id ) {
        global $wpdb;
        $mid = $wpdb->get_results( $wpdb->prepare("SELECT * FROM $wpdb->postmeta WHERE post_id = %d", $post_id) );
        if( $mid != '' )
            return $mid;
            
            return false;
    }
    
    /**
     * Load complete usermeta
     */
    function get_complete_usermeta( $user_id, $meta_key ) {
        global $wpdb;
        $mid = $wpdb->get_results( $wpdb->prepare("SELECT * FROM $wpdb->usermeta WHERE user_id = %d AND meta_key = %s", $user_id, $meta_key) );
        if( $mid != '' )
            return $mid;
            
            return false;
    }
    
    /**
     * Load all posts-IDs with lernerlis a user is interested in
     */
    function get_lernerliposts_for_user( $user_id, $filter = array() ) {
        global $wpdb;
        $where = " ( ";
        foreach($filter as $f) {
            $where .= " meta_value LIKE \"%:".intval($f)."\" OR ";
        }
        $where = preg_replace("/ OR $/", ")", $where);
        if( empty($filter) ) $where = " TRUE ";
        $usermetas = $wpdb->get_results( $wpdb->prepare("SELECT meta_value FROM $wpdb->usermeta WHERE user_id = %d AND meta_key = %s AND $where", $user_id, self::LERNERLI_id) );
        $pids = array();
        foreach($usermetas as $u) {
            list($lernerli,$stufe) = explode(":", $u->meta_value);            
            $ps = $wpdb->get_col( $wpdb->prepare("SELECT post_id FROM $wpdb->postmeta WHERE meta_id = %d AND meta_key = %s group by post_id", intval($lernerli), self::LERNERLI_id) );
            $pids = array_merge($pids, $ps);
        }
        return array_unique($pids);
    }
    
}

?>